@@ -36,8 +36,6 @@ fi
 # Create ipa-rescue-config directory for rescue password
 sudo mkdir -p /etc/ipa-rescue-config
 
-export PYTHONOPTIMIZE=1
-
 # Setup DHCP network
 configure_dhcp_network() {
     for pidfile in `ls /var/run/udhcpc*.pid`; do
@@ -67,10 +65,12 @@ configure_dhcp_network() {
 # Configure networking, use custom udhcpc script to handle MTU option
 configure_dhcp_network
 
+mkdir -p /etc/ironic-python-agent.d/
+
 # Run IPA
 echo "Starting Ironic Python Agent:"
 date
-ironic-python-agent 2>&1 | tee /var/log/ironic-python-agent.log
+ironic-python-agent --config-dir /etc/ironic-python-agent.d/ 2>&1 | tee /var/log/ironic-python-agent.log
 
 
 create_rescue_user() {
